@@ -11,28 +11,6 @@ from ignore.commands import ignore
 from compare.commands import compare
 from lesson.commands import lesson
 
-def run_config(command):
-    api_endpoint = 'https://firestore.googleapis.com/v1/projects/gitutor/databases/(default)/documents/metrics/'
-
-    path = os.path.dirname(__file__)
-    config_file = path + '/.gitutor_config'
-
-    with open(config_file, 'r') as _:
-        flag = int(_.read())
-
-    if flag == 1:
-        fields = {
-            "fields": {
-                "command": {"stringValue": command},
-                "date": {"timestampValue": datetime.now().strftime('%Y-%m-%dT%H:%M:%SZ')}
-            }
-        }
-
-        response = requests.post(api_endpoint, json = fields)
-
-        with open(config_file, 'w') as _:
-            _.write('0')
-
 
 class CustomGroup(click.Group):
     def invoke(self, ctx):
@@ -54,7 +32,6 @@ def cli(ctx):
     #Check ctx was initialized
     ctx.ensure_object(dict)
 
-    run_config(ctx.invoked_subcommand)
     
     if ('--help' not in ctx.obj['args']) and (ctx.invoked_subcommand != 'init') and ctx.invoked_subcommand != 'lesson':
         try:
